==> tdf?file=1&path=frealign_v8.11_130826.tar.gz: frealign_v8.11/src/psearch.f <==
C**************************************************************************
      SUBROUTINE PSEARCH(NSAM,IRAD,AMAG,SPEC,SPEQ,A3DF,A3DS,
     +			 MAXR1,MAXR2,PHI,THETA,PSI,DSHX,DSHY,
     +			 PRESA,SANG,NSANG,CCD,CCC,CCS,CBUF,
     +			 IQUADMAX,MASK,RBFACT,SINCLUT,IPAD,
     +                   RBUF,FSCT,IEWALD,THETATR,CTFF,CTFS,
     +                   RI2,RI3,RIH,HALFW,TESTPAR,IPMAX,ASYM)
C**************************************************************************
C  Searches for 5 parameters describing orientation and position using 
C  cross-correlation method, but also calculates average phase residual.
C  Calls CCP and uses function PRES.
C  Used in LMAIN.
C  MW added IEWALD, THETATR for Ewald sphere correction (used in CCP)
C**************************************************************************
      IMPLICIT NONE

      INTEGER NSAM,MAXR1,MAXR2,IRAD,NSANG,I,I3,IQUAD,J
      INTEGER IQUADMAX,MASK(5),IPAD,IEWALD,IPMAX,K,KK
      REAL XPAR(5),SANG(*),CCMAX,PI,CCD(*),PRESA
      REAL PHI,THETA,PSI,DSHX,DSHY,AMAG,CC,RBUF
      REAL PHI1,THETA1,PSI1,RBFACT,SINCLUT(*),FSCT(*)
      REAL RI2,RI3,RIH,HALFW,TESTPAR(6,*)
      PARAMETER  (PI=3.1415926535897)
      COMPLEX SPEC(*),SPEQ(*),CCC(*),CCS(*)
      COMPLEX A3DF(*),A3DS(*),CBUF(*),DUMC,CTFF(*),CTFS(*)
      REAL THETATR
      CHARACTER ASYM*3
C**************************************************************************
      CCMAX=-1E30
      DO 30 K=1,IPMAX
        TESTPAR(6,K)=0.0
30    CONTINUE
      DO 10 I=1,NSANG
      	I3=3*I
      	XPAR(1)=MASK(1)*SANG(I3-2)+PHI
        IF (ASYM(1:1).EQ.'H') THEN
      	  XPAR(2)=MASK(2)*(SANG(I3-1)-THETA)+THETA
        ELSE
          XPAR(2)=MASK(2)*SANG(I3-1)+THETA
        ENDIF
      	XPAR(3)=MASK(3)*SANG(I3)+PSI
      	IF (XPAR(1).GT.PI) XPAR(1)=XPAR(1)-2.0*PI
      	IF (XPAR(2).GT.PI) XPAR(2)=XPAR(2)-2.0*PI
      	IF (XPAR(3).GT.PI) XPAR(3)=XPAR(3)-2.0*PI
      	XPAR(4)=0.0
      	XPAR(5)=0.0
      	CALL CCP(NSAM,IRAD,AMAG,SPEC,SPEQ,A3DF,A3DS,RBUF,
     +		 MAXR1,MAXR2,XPAR(1),XPAR(2),XPAR(3),XPAR(4),XPAR(5),
     +		 CC,CCD,CCC,CCS,CBUF,IQUAD,MASK,RBFACT,SINCLUT,IPAD,
     +           IEWALD,THETATR,CTFF,CTFS,RI2,RI3,RIH,HALFW,IQUADMAX)
      	IF (XPAR(3).GT.PI) XPAR(3)=XPAR(3)-2.0*PI
C        if (i.eq.68) cc=cc+1.0
C        if (CC.GT.CCMAX) THEN
C        if ((i/2)*2.eq.i) then
C        print *,-i/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc,"*"
C        else
C        print *,(i+1)/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc,"*"
C        endif
C        else
C        if ((i/2)*2.eq.i) then
C        print *,-i/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc
C        else
C        print *,(i+1)/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc
C        endif
C        endif
        DO 40 K=1,IPMAX
          IF (CC.GT.TESTPAR(6,K)) THEN
            DO 50 KK=IPMAX,K+1,-1
              DO 60 J=1,6
                TESTPAR(J,KK)=TESTPAR(J,KK-1)
60            CONTINUE
50          CONTINUE
            DO 20 J=1,5
              TESTPAR(J,K)=XPAR(J)
20          CONTINUE
            TESTPAR(6,K)=CC
            GOTO 41
          ENDIF
40      CONTINUE
C
41      CONTINUE
      	IF (CC.GT.CCMAX) THEN
      	  CCMAX=CC
      	  PHI1=XPAR(1)
      	  THETA1=XPAR(2)
      	  PSI1=XPAR(3)
      	  DSHX=XPAR(4)
      	  DSHY=XPAR(5)
C		on entry to PSEARCH, DSHX and DSHY are normally zero
      	ENDIF
10    CONTINUE
      PHI=PHI1
      THETA=THETA1
      PSI=PSI1
C      write(*,11) CCMAX,PRESA*180.0/PI
11    format(' Exiting  PSEARCH with CCMAX, PRES',2F8.3)
      RETURN
      END

==> tdf?file=1&path=frealign_v9.05_131002.tar.gz: frealign_v9.05/src/psearch.f <==
C*
C* Copyright 2013 Howard Hughes Medical Institute.
C* All rights reserved.
C* Use is subject to Janelia Farm Research Campus Software Copyright 1.1
C* license terms ( http://license.janelia.org/license/jfrc_copyright_1_1.html )
C*
C**************************************************************************
      SUBROUTINE PSEARCH(NSAM,IRAD,AMAG,SPEC,SPEQ,A3DF,A3DS,
     +			 MAXR1,MAXR2,PHI,THETA,PSI,DSHX,DSHY,
     +			 SANG,NSANG,CCD,CCC,CCS,CBUF,
     +			 IQUADMAX,PMASK,RBFACT,SINCLUT,IPAD,
     +                   RBUF,FSCT,IEWALD,THETATR,CTFF,CTFS,
     +                   RI2,RI3,RIH,HALFW,TESTPAR,IPMAX)
C**************************************************************************
C  Searches for 5 parameters describing orientation and position using 
C  cross-correlation method.
C  Calls CCP.
C  Used in LMAIN.
C**************************************************************************
      IMPLICIT NONE

      INTEGER NSAM,MAXR1,MAXR2,IRAD,NSANG,I,I3,IQUAD,J
      INTEGER IQUADMAX,PMASK(*),IPAD,IEWALD,IPMAX,K,KK
      REAL XPAR(5),SANG(*),CCMAX,PI,CCD(*)
      REAL PHI,THETA,PSI,DSHX,DSHY,AMAG,CC,RBUF
      REAL PHI1,THETA1,PSI1,RBFACT,SINCLUT(*),FSCT(*)
      REAL RI2,RI3,RIH,HALFW,TESTPAR(6,*)
      PARAMETER  (PI=3.1415926535897)
      COMPLEX SPEC(*),SPEQ(*),CCC(*),CCS(*)
      COMPLEX A3DF(*),A3DS(*),CBUF(*),DUMC,CTFF(*),CTFS(*)
      REAL THETATR
C**************************************************************************
      CCMAX=-1E30
      DO 30 K=1,IPMAX
        TESTPAR(6,K)=0.0
30    CONTINUE
      DO 10 I=1,NSANG
      	I3=3*I
        XPAR(1)=PMASK(1)*SANG(I3-2)+PHI
        XPAR(2)=PMASK(2)*SANG(I3-1)+THETA
        XPAR(3)=PMASK(3)*SANG(I3)+PSI
      	IF (XPAR(1).GT.PI) XPAR(1)=XPAR(1)-2.0*PI
      	IF (XPAR(2).GT.PI) XPAR(2)=XPAR(2)-2.0*PI
      	IF (XPAR(3).GT.PI) XPAR(3)=XPAR(3)-2.0*PI
      	XPAR(4)=0.0
      	XPAR(5)=0.0
      	CALL CCP(NSAM,IRAD,AMAG,SPEC,SPEQ,A3DF,A3DS,RBUF,
     +		 MAXR1,MAXR2,XPAR(1),XPAR(2),XPAR(3),XPAR(4),XPAR(5),
     +		 CC,CCD,CCC,CCS,CBUF,IQUAD,PMASK,RBFACT,SINCLUT,IPAD,
     +           IEWALD,THETATR,CTFF,CTFS,RI2,RI3,RIH,HALFW,IQUADMAX)
      	IF (XPAR(3).GT.PI) XPAR(3)=XPAR(3)-2.0*PI
C        if (i.eq.68) cc=cc+1.0
C        if (CC.GT.CCMAX) THEN
C        if ((i/2)*2.eq.i) then
C        print *,-i/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc,"*"
C        else
C        print *,(i+1)/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc,"*"
C        endif
C        else
C        if ((i/2)*2.eq.i) then
C        print *,-i/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc
C        else
C        print *,(i+1)/2,XPAR(1)/pi*180,XPAR(2)/pi*180,XPAR(3)/pi*180,
C     +             cc
C        endif
C        endif
        DO 40 K=1,IPMAX
          IF (CC.GT.TESTPAR(6,K)) THEN
            DO 50 KK=IPMAX,K+1,-1
              DO 60 J=1,6
                TESTPAR(J,KK)=TESTPAR(J,KK-1)
60            CONTINUE
50          CONTINUE
            DO 20 J=1,5
              TESTPAR(J,K)=XPAR(J)
20          CONTINUE
            TESTPAR(6,K)=CC
            GOTO 41
          ENDIF
40      CONTINUE
C
41      CONTINUE
      	IF (CC.GT.CCMAX) THEN
      	  CCMAX=CC
      	  PHI1=XPAR(1)
      	  THETA1=XPAR(2)
      	  PSI1=XPAR(3)
      	  DSHX=XPAR(4)
      	  DSHY=XPAR(5)
C		on entry to PSEARCH, DSHX and DSHY are normally zero
      	ENDIF
10    CONTINUE
      PHI=PHI1
      THETA=THETA1
      PSI=PSI1
      RETURN
      END
